# 2023-03-16 - Child Chain Gauge Factory

Deployment of the `ChildChainGaugeFactory` V2, for liquidity gauges to be used with pools on networks other than Ethereum.
This version simplifies the system to distribute BAL and allows veBAL boosts on L2s and sidechains other than Mainnet.

## Useful Files

- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Optimism mainnet addresses](./output/optimism.json)
- [Gnosis mainnet addresses](./output/gnosis.json)
- [Avalanche mainnet addresses](./output/avalanche.json)
- [Polygon zkeVM mainnet addresses](./output/zkevm.json)
- [Base mainnet addresses](./output/base.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`ChildChainGauge` artifact](./artifact/ChildChainGauge.json)
- [`ChildChainGaugeFactory` artifact](./artifact/ChildChainGaugeFactory.json)
